

;/////////////////////////////////////////////////////
;/////////////// GRAPHICS FUNCTIONS //////////////////
;/////////////////////////////////////////////////////

;-----------------------------------------------------
;       DrawWindow2
;
;Input>	a0.l : Address of api92Rect structure
;	a1.l : Title of Window
;Out>	No register modified
;
; Format of api92Rect structure :
;  x.B : X1
;  x.B : Y1
;  x.B : X2
;  x.B : Y2
;-----------------------------------------------------

;-----------------------------------------------------
;       DrawWindow
;
;Input>	a0.l : Address of api92Win structure
;Out>	No register modified
;
; Format of api92Win structure :
;  x.B : X1
;  x.B : Y1
;  x.B : X2
;  x.B : Y2
;  (..) : Null terminated string
;-----------------------------------------------------

;-----------------------------------------------------
;       DrawString
;
;Input>	a0.l : Address of api92String structure
;Out>	No register modified
;
; Format of api92String structure :
;  x.B : X
;  x.B : Y
;  (..) : String
;-----------------------------------------------------

;-----------------------------------------------
;  	DrawStringSpecial
;
; The use of this function is to draw a string
; without passing parametters with the stack.
; Moreover it destroys no register.
; This function is used for size-optimization in
; programs
;
;input> d0.w : X
;       d1.w : Y
;       a1.l : Address of null terminated string
;out>	No Register Modified
;----------------------------------------------- 

;-----------------------------------------------
;  	DrawCharSpecial
;
; The use of this function is to draw a char
; without passing parametters with the stack.
; Moreover it destroys no register.
; This function is used for size-optimization in
; programs
;
;input> d0.w : X
;       d1.w : Y
;       d2.w : Char
;out>	No Register Modified
;----------------------------------------------- 

;-----------------------------------------------------
;       DrawEraseRect
;
;Input>	a0.l : Address of api92Rect structure
;Out>	a0 = a0 + 4
;	No Other registers modified
;
; Format of api92Rect structure :
;  x.B : X1
;  x.B : Y1
;  x.B : X2
;  x.B : Y2
;-----------------------------------------------------

;-----------------------------------------------------
;       SetFont
;
; Set the current Font used. It has the advantage
; of changing no register. 
; (Used for size-optimization)
;
;Input>	d0.w : Font Index : 	0 = small (variable x 6)
;				1 = medium (6 x 8)
;				2 = large (8*10)
;Out>	No register modified
;-----------------------------------------------------

;-----------------------------------------------------
;       GetFont
;
; Get the current Font used. It has the advantage
; of changing only the d0 register.
;
;Input>	Nothing
;
;Out>	d0.w : Font Index : 	0 = small (variable x 6)
;				1 = medium (6 x 8)
;				2 = large (8*10)
;
;	No Other register modified
;-----------------------------------------------------

;-----------------------------------------------------
;       GetFontWidthHeight
;
; Get the width and the height of current font 
; used
; Notice that the real width in small font is
; variable. The function will return 6
;
;Input>	Nothing
;
;Out>	d0.w : Font Width
;	d1.w : Font Height
;
;	No Other register modified
;-----------------------------------------------------

;------------------------------------------------------
;	InvertArea
;
; Invert a non-aligned area on the screen
;
;Input>	d0.w : X
;	d1.w : Y
;	d2.w : Width (in pixels)
;	d3.w : Height (in pixels)
;Out>	No Register Modified
;------------------------------------------------------

;-----------------------------------------------------
;       ScreenToBuffer
;
; Copy the entire screen into a 3840 bytes buffer
;
;Input>	a1.l : Address of Buffer
;Out>	No register modified
;-----------------------------------------------------

;-----------------------------------------------------
;       BufferToScreen
;
; Copy the contents of a 3840 bytes buffer to the screen
;
;Input>	a1.l : Address of Buffer
;Out>	No register modified
;-----------------------------------------------------



;/////////////////////////////////////////////////////
;//////////////// UTILITY FUNCTIONS //////////////////
;/////////////////////////////////////////////////////


;------------------------------------------------------
;	DecimalToStr	
;
; This function convert using decimal base a number 
; to a null-terminated string
;
;Input>	d0.l : The number to convert
;	a0.l : Address of END of thestring buffer 
;		( must be large enough )
;Out>	a0.l : address of the beginning of the string
;	No Other Register Modified
;------------------------------------------------------

;------------------------------------------------------
;	HexaToStr	
;
; This function convert using hexadecimal base a number 
; to a null-terminated string
;
;Input>	d0.l : The number to convert
;	d1.w : Number of digit-1
;	a0.l : Address of string buffer ( must be large
;		enough )
;Out>	No Register Modified
;------------------------------------------------------

;------------------------------------------------------
;	GetFreeRAM
;
; Get free RAM
;
;Input>	Nothing
;Out>	d0.l : Free RAM size
;	No Other Register Modified
;------------------------------------------------------

;------------------------------------------------------
;	DEREFd0a0
;
; This function is used for size optimization : with only
; one library call, it returns the address of a handle,
; modifing only a0
;
;Input>	d0.w : The handle
;Out>	a0.l : The address of the handle in d0
;	No Other Register Modified
;-------------------------------------------------------

;-------------------------------------------------------
;	SetIntVector
;
; Set an interrupt vector
; This function can be used both to set a new
; interrupt vector and to restore it.
; You MUST ALWAYS save the address of the previous
; routine given in a1.
;
; You can use the ??_VECTOR constants of api92cst.h
;
;input>	a0 : vector address to set
;	a1 : address of the new routine
;
;out>	a1 : addr of previous routine
;	No Other Register Modified
;-------------------------------------------------------


;-------------------------------------------------------
;	InputStr
; 
;Input>	a0.l : address of a api92Input structure
;
; Format of api92Input structure
;  x.B : Input Flag
;       xxxxxxx1  -> masked input
;       xxxxxx1x  -> convert in lower case
;       xxxxx1xx  -> allow only '0'..'9'
;
;  x.B : Char used when masked input
;  x.B : Max number of chars
;  x.B : X
;  x.B : Y
;  (xx).b : Buffer where put chars. Must be large
;	    enough
;
;Out>	d0.w : 	0 if ESC.
;               else nb of chars input
;     	a0.l : Address of the beginning of the buffer
;------------------------------------------------------

;------------------------------------------------------
;	ListView
;
; This function offers a VERY powerful universal 
; listview component with scrolling. It can be
; used in a lot of programs !
;
;Input>	d0.w : X
;	d1.w : Y
;	d2.w : NbItem-1
;	d3.w : NbItemPerPage-1
;	d5.w : List Width ( in chars )
;	d4.b : Flags
;		xxxxxxx1 : If set don't draw the rect
;		xxxxxx1x : If set all the items must have
;			   the size of d6 chars (including
;			   zero terminated char) Useful
;			   for constant-size items list.
;		xxxxx1xx : If set call an api92CallBackDrawItem
;			   function pointed by a3 each time an item
;			   is drawn.
;
;	d6.w : Constant size of items if flag xxxxxx1x is set
;	a0.l : Addr of list data. If flag xxxxxx1x is set all
;		the zero-terminated items must have the same size,
;		else it is just an array of zero-terminated
;		strings.
;	a1.l : Address of a api92CallBackKeys function :
;		It is the address of a function called when
;		a key is pressed. 
;	a3.l : Address of a api92CallBackDrawItem function if flag
;		xxxxx1xx is set
;
;Out>	d0.w : The return value of the api92CallBackKeys 
;		function
;	No Other Register Modified
;
;
; api92CallBackeys function Format :
;	When the function is called :
;	- d0.w : key pressed
;	- d6.w : Zero based index of the selected item
;	The function can return :
;	- d0.w : 0 = continue
;		 $FFFF = redraw list
;		 else exit ListView component
;
; api92CallBackDrawItem function format :
;	When the function is called :
;	- d0.w : ItemX
;	- d1.w : ItemY
;	- d3.w : List Width
;	- d6.w : Zero based index of the selected item
;	- a1.l : Item string
;	The function returns nothing
;
;------------------------------------------------------

;------------------------------------------------------
;		ListView2
;
;Input>	a2.l : Address of a api92ListView structure
;	a0.l : Addr of list data. If flag xxxxxx1x is set all
;		the zero-terminated items must have the same size,
;		else it is just an array of zero-terminated
;		strings.
;	a1.l : Address of a api92CallBackKeys function :
;		It is the address of a function called when
;		a key is pressed. 
;	a3.l : Address of a api92CallBackDrawItem function if flag
;		xxxxx1xx is set
;
;Out>	d0.w : The return value of the api92CallBackKeys 
;		function
;	No Other Register Modified
;
;
; api92CallBackeys function Format :
;	When the function is called :
;	- d0.w : key pressed
;	- d6.w : Zero based index of the selected item
;	The function can return :
;	- d0.w : 0 = continue
;		 $FFFF = redraw list
;		 else exit ListView component
;
; api92CallBackDrawItem function format :
;	When the function is called :
;	- d0.w : ItemX
;	- d1.w : ItemY
;	- d3.w : List Width
;	- d6.w : Zero based index of the selected item
;	- a1.l : Item string
;	The function returns nothing
;
;Format of api92ListView structure :
;	x.w	: NbItem-1
;	x.B	: X
;	x.B	: Y
;	x.B	: NbItemPerPage-1
;	x.B	: Flags
;		xxxxxxx1 : If set don't draw the rect
;		xxxxxx1x : If set all the items must have
;			   the size of d6 chars (including
;			   zero terminated char) Useful
;			   for constant-size items list.
;		xxxxx1xx : If set call an api92CallBackDrawItem
;			   function pointed by a3 each time an item
;			   is drawn.
;
;	x.B	: List Width ( in chars )
;	x.B	: Items Size if flag xxxxxx1x is set
;------------------------------------------------------




;---------------------------------------------------
;	GetFileExt
;
; This function is used to know the extension
; of a file.
; Use the EXT_??? constants of api92cst.h to
; know the extension of the file. (EXT_ASM,
; EXT_GDB, EXT_PIC... )
;
; To get the 4 chars extension name, use the
; ExtIDToStr function or the ExtStrTbl address
;
;input> a0.l : address of the beginning of file
;out>   d2.w : Extension ID of the file
;
;	No Other Register Modified
;---------------------------------------------------

;---------------------------------------------------
;	ExtID_Str
;
; This function returns the 4 chars null terminated
; string associated with an extension constant.
; (EXT_ASM, EXT_GDB...)
;
; This function is used to keep compatibility
; with the next versions of Api92, while using
; a alphabetic sorted list of extension names.
;
;Input>	d2.w : Extension ID (EXT_ASM, EXT_PIC... )
;out>	a1.l : Address of the null terminated 
;		extension name
;
; 	No Other Register Modified
;---------------------------------------------------

;---------------------------------------------------
; 	ExtStrTbl
;
; With :
;	lea api92::ExtStrTbl,ax
; you will get the address of the extension name list.
;
; Each item has the following format :
; 4.b : 4 chars
; 1.b : 0 terminated string
;---------------------------------------------------

;---------------------------------------------------
; 	ExtStrIndexTbl
;
; With :
;	lea api92::ExtStrIndexTbl,ax
; you will a table used to convert the extension
; Identifier (ID) to the string zero based index.
; Each entry of the table is a byte.
;---------------------------------------------------

;----------------------------------------------------
; 	ExtID_Picture
;
; Return the address of the 8x8 picture associated
; with a extension ID (EXT_ASM, EXT_STR...)
;
;Input>	d2.w : Extension ID
;Out>	a0.l : address of the 8x8 pixel picture
;----------------------------------------------------


api92::DrawWindow 		equ api92@0000
api92::DrawWindow2		equ api92@0001
api92::DrawString		equ api92@0002		;DrawString
api92::DrawStringSpecial	equ api92@0003		;DrawStringSpecial
api92::DrawCharSpecial		equ api92@0004		;DrawCharSpecial
api92::DrawEraseRect		equ api92@0005		;DrawEraseRect
api92::SetFont			equ api92@0006		;SetFont
api92::GetFont			equ api92@0007		;GetFont
api92::GetFontWidthHeight	equ api92@0008
api92::InvertArea		equ api92@0009		;InvertArea
api92::ScreenToBuffer		equ api92@000A		;ScreenToBuffer
api92::BufferToScreen		equ api92@000B		;BufferToScreen

api92::DecimalToStr		equ api92@000C		;DecimalToStr
api92::HexaToStr		equ api92@000D		;HexaToStr
api92::GetFreeRAM		equ api92@000E		;GetFreeRam
api92::DEREFd0a0		equ api92@000F		;DEREFd0a0
api92::SetIntVector		equ api92@0010		;SetIntVector
api92::InputStr			equ api92@0011		;InputStr

api92::ListView			equ api92@0012		;ListView
api92::ListView2		equ api92@0013		;ListView2

api92::GetFileExt		equ	api92@0014	;GetFileExt
api92::ExtID_Str		equ	api92@0015	;ExtID_Str
api92::ExtStrTbl		equ	api92@0016	;ExtStrTbl
api92::ExtStrIndexTbl		equ	api92@0017	;ExtStrIDTbl
api92::ExtID_Picture		equ	api92@0018	;ExtID_Picture
